@@ -35,10 +35,11 @@ impl Record {
             match res {
                 ReadRecordResult::InputEmpty => continue,
                 ReadRecordResult::OutputFull => {
-                    fields.resize(std::cmp::max(4, fields.len().checked_mul(2).unwrap()), 0)
+                    fields.resize(std::cmp::max(4, fields.len().checked_mul(2).unwrap()), 0);
                 }
+
                 ReadRecordResult::OutputEndsFull => {
-                    ends.resize(std::cmp::max(4, ends.len().checked_mul(2).unwrap()), 0)
+                    ends.resize(std::cmp::max(4, ends.len().checked_mul(2).unwrap()), 0);
                 }
                 ReadRecordResult::Record => {
                     unsafe {
@@ -72,10 +73,10 @@ impl Record {
             match res {
                 ReadRecordResult::InputEmpty => continue,
                 ReadRecordResult::OutputFull => {
-                    fields.resize(std::cmp::max(4, fields.len().checked_mul(2).unwrap()), 0)
+                    fields.resize(std::cmp::max(4, fields.len().checked_mul(2).unwrap()), 0);
                 }
                 ReadRecordResult::OutputEndsFull => {
-                    ends.resize(std::cmp::max(4, ends.len().checked_mul(2).unwrap()), 0)
+                    ends.resize(std::cmp::max(4, ends.len().checked_mul(2).unwrap()), 0);
                 }
                 ReadRecordResult::Record => {
                     unsafe {
@@ -289,7 +290,7 @@ where
             match self.record_iter.next() {
                 Some(r) => {
                     if let Some(r) = Record::new(&mut csv_reader, r) {
-                        rows.push(r)
+                        rows.push(r);
                     }
                     // Skip invalid rows.
                 }
@@ -371,7 +372,7 @@ where
         match row.get(col_idx) {
             Some(s) if !s.is_empty() => {
                 let t = parse(s).unwrap_or_default();
-                builder.append_value(t).expect("never fails")
+                builder.append_value(t).expect("never fails");
             }
             _ => builder
                 .append_value(T::Native::default())
@@ -423,7 +424,7 @@ mod tests {
     use itertools::izip;
     use std::net::Ipv4Addr;
 
-    fn get_test_data() -> (Vec<Vec<u8>>, Vec<Column>) {
+    fn test_data() -> (Vec<Vec<u8>>, Vec<Column>) {
         let c0_v: Vec<i64> = vec![1, 3, 3, 5, 2, 1, 3];
         let c1_v: Vec<_> = vec!["111a qwer", "b", "c", "d", "b", "111a qwer", "111a qwer"];
         let c2_v: Vec<Ipv4Addr> = vec![
@@ -550,7 +551,7 @@ mod tests {
             FieldParser::Utf8,
             FieldParser::Binary,
         ];
-        let (data, columns) = get_test_data();
+        let (data, columns) = test_data();
         let mut reader = Reader::new(data.iter().map(|d| d.as_slice()), data.len(), &parsers);
         let result: Vec<Column> = if let Some(batch) = reader.next_batch().unwrap() {
             batch.columns().iter().map(|c| c.clone().into()).collect()
